#### USER GROWTH PROFILE ##############################################

# This file calculates the number of users in each state-geotype class
# for each year (the 'user growth profile'). The user growth profile is used
# in subsequent modules to estimate the number of user-related items.

# import user data
USERS <- read.xlsx(xlsxFile = INPUTS, sheet = 'Total.Users' , startRow = 1)
USERS <- select(USERS, STATE, GEOTYPE, VALUE, GROWTH.RATE)


# User growth profile function --------------------------------------------

# This function calculates the number of users in each state-geotype class
# for year t
User.growth.profile <- function(t){
  OUTPUT <- USERS$VALUE * ((1+USERS$GROWTH.RATE)^(t-1))
}

# Apply the user growth profle function for each year in the time horizon
USER <- lapply(T.LIST, User.growth.profile)
# Reshape as dataframe and assign column names
USER <- as.data.frame(USER)
colnames(USER) <- c(1:T)

rm(User.growth.profile)

# Change in number of users from year to year -----------------------------

# This section calculates the number of additional users in each
# state-geotype class in each year.

# Function for calculating year-on-year change
Change <- function(x){
  # For each year t, the number of additional users is given by the number 
  # of users in year t, less the number of users in year t-1
  OUTPUT <- if(x>1){                 
    USER[x] - USER[x-1]       
  # Except in year 1, when the number of additional users is given by 
  # the number of users in year 1    
  }else{                            
    USER[x]                      
  }
}

# Apply the function for calculating year-on-year change for each year 
# in the time horizon
USER.ADDITIONAL <- lapply(T.LIST,Change)
# Reshape as a data frame and assign column names
USER.ADDITIONAL <- as.data.frame(USER.ADDITIONAL)
colnames(USER.ADDITIONAL) <- c(1:T)

# RESHAPE -----------------------------------------------------------------

# This section rejoins numeric outputs from functions with state-geotype 
# descriptors

# Rejoin numeric outputs with state-geotype descriptors
USER.ADDITIONAL <- cbind(USERS[c('STATE','GEOTYPE')], 
                         USER.ADDITIONAL)

# Rejoin numeric outputs with state-geotype descriptors
USER <- cbind(USERS[c('STATE','GEOTYPE')], 
                     USER)

rm(USERS)
